@@ -2,11 +2,13 @@
 #this repository contains the full copyright notices and license terms.
 {
     'name': 'Sale',
+    'name_bg_BG': 'Продажби',
     'name_de_DE': 'Verkauf',
     'name_es_CO': 'Ventas',
     'name_es_ES': 'Venta',
     'name_fr_FR': 'Vente',
-    'version': '1.8.1',
+    'name_nl_NL': 'Verkoop',
+    'version': '2.0.0',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -24,6 +26,21 @@ With the possibilities:
         - Manual
         - On Order Confirmed
         - On Invoice Paid
+''',
+    'description_bg_BG': ''' Задаване на поръчка за продажба.
+ - Добавяне на информация за продажба на продукт.
+ - Задаване на продажна цена като ценова листа.
+
+Със следните възможности:
+    - проследяване на състоянията на фактура и доставка от поръчката за продажба
+    - задаване на начини на фактуриране:
+        - Ръчно
+        - При потвърждаване на поръчката
+        - При изпращане
+    - задаване на начина на доставка:
+        - Ръчно
+        - При потвърждаване на поръчката
+        - При плащане на фактурата
 ''',
     'description_de_DE': ''' - Dient der Erstellung von Verkaufsvorgängen (Entwurf, Angebot, Auftrag).
  - Fügt den Artikeln Einkaufsinformationen hinzu.
@@ -83,6 +100,21 @@ Avec la possibilité:
         - Manuelle
         - Sur confirmation de la commande
         - Au paiement de la facture
+''',
+	'description_nl_NL': '''Verkoopmodule.
+Voegt verkoopinformatie toe aan producten.
+Zet de catalogusprijs als verkoopprijs.
+
+Biedt mogelijkheden tot:
+    - het volgen van de factuur en de aflevering vanuit de offerte.
+    - het instellen van de factuurafhandeling:
+        - Handmatig
+        - Bij opdrachtbevestiging
+        - Bij aflevering
+    - het instellen van de aflevering:
+        - Handmatig
+        - Bij opdrachtbevestiging
+        - Na betaling
 ''',
     'depends': [
         'company',
@@ -103,9 +135,11 @@ Avec la possibilité:
         'party.xml',
     ],
     'translation': [
+        'bg_BG.csv',
         'de_DE.csv',
         'es_CO.csv',
         'es_ES.csv',
         'fr_FR.csv',
+        'nl_NL.csv',
     ],
 }
